import Oasys.gRPC


# Metaclass for static properties and constants
class ReadType(type):
    _consts = {'CSV_COMMA', 'CSV_SPACE', 'CSV_TAB', 'CSV_XYXY', 'CSV_XYYY', 'DIADEM_COMMENT', 'DIADEM_NAME', 'EQUATION_CURVE_VARS', 'EQUATION_X_OR_CURVE', 'EQUATION_X_VALS', 'ISO_CHANNEL_CODE', 'ISO_CHANNEL_LABEL', 'ISO_MULTIPLE_CHANNELS', 'ISO_SINGLE_CHANNEL', 'LSPP_CURVE_FILE', 'LSPP_XY_PAIRS'}

    def __getattr__(cls, name):
        if name in ReadType._consts:
            return Oasys.THIS._connection.classGetter(cls.__name__, name)

        raise AttributeError


class Read(Oasys.gRPC.OasysItem, metaclass=ReadType):


    def __del__(self):
        if not Oasys.THIS._connection:
            return

        Oasys.THIS._connection.destructor(self.__class__.__name__, self._handle)


    def __getattr__(self, name):
        raise AttributeError


    def __setattr__(self, name, value):
# Set the property locally
        self.__dict__[name] = value


# Static methods
    def Bulk(filename, options=Oasys.gRPC.defaultArg):
        """
        Reads a Bulk Data file into T/HIS

        Parameters
        ----------
        filename : String
            Name of Bulk Data file to read
        options : dict
            Optional. Options which give you greater control of reading a Bulk file:

        Returns
        -------
        None
            No return value
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "Bulk", filename, options)

    def CSV(filename, options=Oasys.gRPC.defaultArg):
        """
        Reads a CSV file into T/HIS

        Parameters
        ----------
        filename : String
            Name of CSV file to read
        options : dict
            Optional. Options which give you greater control of reading a CSV file:

        Returns
        -------
        None
            No return value
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "CSV", filename, options)

    def Cur(filename, options=Oasys.gRPC.defaultArg):
        """
        Reads a Curve file into T/HIS

        Parameters
        ----------
        filename : String
            Name of Curve file to read
        options : dict
            Optional. Options which give you greater control of reading a Curve file:

        Returns
        -------
        None
            No return value
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "Cur", filename, options)

    def DIAdem(filename, x_axis_channel, options=Oasys.gRPC.defaultArg):
        """
        Reads a DIAdem file into T/HIS

        Parameters
        ----------
        filename : String
            Name of DIAdem header file to read
        x_axis_channel : integer
            Index of the channel to use as X-axis values. If this is 0 then the X-values can be generated from a start value and an interval in the following two arguments
        options : dict
            Optional. Options which give you greater control of reading the Diadem file:

        Returns
        -------
        None
            No return value
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "DIAdem", filename, x_axis_channel, options)

    def Equation(formula, options=Oasys.gRPC.defaultArg):
        """
        Create a curve from a user-defined equation

        Parameters
        ----------
        formula : String
            Equation string
        options : dict
            Optional. Options which give you greater control of reading the Diadem file:

        Returns
        -------
        None
            No return value
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "Equation", formula, options)

    def ISO(filename, options=Oasys.gRPC.defaultArg):
        """
        Reads an ISO file into T/HIS

        Parameters
        ----------
        filename : String
            Name of ISO file to read
        options : dict
            Optional. Options which give you greater control of reading an ISO file:

        Returns
        -------
        None
            No return value
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "ISO", filename, options)

    def Key(filename, options=Oasys.gRPC.defaultArg):
        """
        Reads a Keyword file into T/HIS

        Parameters
        ----------
        filename : String
            Name of Keyword file to read
        options : dict
            Optional. Options which give you greater control of reading a Keyword file:

        Returns
        -------
        None
            No return value
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "Key", filename, options)

    def LSPP(filename, options=Oasys.gRPC.defaultArg):
        """
        Reads an LS-PREPOST file into T/HIS

        Parameters
        ----------
        filename : String
            Name of LS-PREPOST file to read
        options : dict
            Optional. Options which give you greater control of reading a Keyword file:

        Returns
        -------
        None
            No return value
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "LSPP", filename, options)




import Oasys.gRPC

# ItemObject not (yet) used in T/HIS but defined here for consistency with PRIMER

class ItemObject(Oasys.gRPC.OasysItem):

    def __del__(self):
        if not Oasys.THIS._connection:
            return

        Oasys.THIS._connection.destructor(self.__class__.__name__, self._handle)


    def __getattr__(self, name):
        return Oasys.THIS._connection.instanceGetter(self.__class__.__name__, self._handle, name)


    def __setattr__(self, name, value):
        Oasys.THIS._connection.instanceSetter(self.__class__.__name__, self._handle, name, value)
        return



import Oasys.gRPC


# Metaclass for static properties and constants
class PageType(type):

    def __getattr__(cls, name):

        raise AttributeError


class Page(Oasys.gRPC.OasysItem, metaclass=PageType):


    def __del__(self):
        if not Oasys.THIS._connection:
            return

        Oasys.THIS._connection.destructor(self.__class__.__name__, self._handle)


    def __getattr__(self, name):
        raise AttributeError


    def __setattr__(self, name, value):
# Set the property locally
        self.__dict__[name] = value


# Static methods
    def AddGraph(page_number, graph_number=Oasys.gRPC.defaultArg, graph_number_to_copy_properties_from=Oasys.gRPC.defaultArg, number_of_graphs=Oasys.gRPC.defaultArg):
        """
        Adds one or more graphs to the specified page

        Parameters
        ----------
        page_number : Integer
            Page number to add graph(s) to
        graph_number : Integer
            Optional. Graph number to add to page. If this argument is 0 or not given, a new graph is created
        graph_number_to_copy_properties_from : Integer
            Optional. If the second argument is 0, this specifies which graph to copy properties from when creating new graphs
        number_of_graphs : Integer
            Optional. If the second argument is 0, this specifies the number of new graphs to create and add to the specified page

        Returns
        -------
        bool
            True if the graph was added, False if failed
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "AddGraph", page_number, graph_number, graph_number_to_copy_properties_from, number_of_graphs)

    def Layout(page_number, layout, num_in_x=Oasys.gRPC.defaultArg, num_in_y=Oasys.gRPC.defaultArg):
        """
        Sets the layout of either all pages or a specified page

        Parameters
        ----------
        page_number : Integer
            Page number for which to set layout. If this argument is 0 then layout will be set on all pages individually. If -1 then the layout will be set globally, as in the 'Graphs' panel
        layout : String or Integer
            Layout specifier. Options are: "wide" or 1 - Tile wide, "tall" or 2 - Tile tall, "1x1" or 3 - 1x1, "2x2" or 4 - 2x2, "3x3" or 5 - 3x3, "xy" or 6 - XxY
        num_in_x : Integer
            Optional. Number of graphs in X-direction if user-defined XxY layout (6)
        num_in_y : Integer
            Optional. Number of graphs in Y-direction if user-defined XxY layout (6)

        Returns
        -------
        bool
            True if the layout was set, False if failed
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "Layout", page_number, layout, num_in_x, num_in_y)

    def RemoveGraph(page_number, graph_number=Oasys.gRPC.defaultArg, lower_end_of_range_for_removing_graphs=Oasys.gRPC.defaultArg, upper_end_of_range_for_removing_graphs=Oasys.gRPC.defaultArg):
        """
        Remove one or more graphs from the specified page

        Parameters
        ----------
        page_number : Integer
            Page number to remove the graph from
        graph_number : Integer
            Optional. Graph number to remove from page. If this argument is 0 or not given, the highest number graph on the page will be removed. If this argument is -1, all graphs will be removed
        lower_end_of_range_for_removing_graphs : Integer
            Optional. If the second argument is 0, this specifies the lower end of the range for removing graphs. All graphs with numbers within the specified range will be removed from the page
        upper_end_of_range_for_removing_graphs : Integer
            Optional. If the second argument is 0, this specifies the upper end of the range for removing graphs. All graphs with numbers within the specified range will be removed from the page. If this argument is not given then it will be set to 32 by default

        Returns
        -------
        bool
            True if the graph was removed, False if failed
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "RemoveGraph", page_number, graph_number, lower_end_of_range_for_removing_graphs, upper_end_of_range_for_removing_graphs)

    def ReturnActivePage():
        """
        Returns the current active page in T/HIS

        Returns
        -------
        int
            integer
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "ReturnActivePage")

    def ReturnGraphs(page_number):
        """
        Returns the graphs on the specified page as a list of Graph objects

        Parameters
        ----------
        page_number : Integer
            Page number for which to return the graphs it contains

        Returns
        -------
        list
            List of Graph objects
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "ReturnGraphs", page_number)

    def SetActivePage(page_number):
        """
        Sets the current active page in T/HIS, returning -1 if the page does not exist or the page number if it does

        Parameters
        ----------
        page_number : Integer
            Page number to set to active page

        Returns
        -------
        bool
            True if the page was set, False if the page does not exist
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "SetActivePage", page_number)




import Oasys.gRPC


# Metaclass for static properties and constants
class EntityType(type):
    _consts = {'AIRBAG', 'AIRBAG_CHAMBER_DATA', 'AIRBAG_CPM_PART_DATA', 'AIRBAG_CPM_SENSORS', 'AIRBAG_CV_PART_DATA', 'AIRBAG_DATA', 'BEAM', 'BEAM_DISCRETE', 'BEAM_NORMAL', 'BEARING', 'BOUNDARY', 'BOUNDARY_DIS_NODAL_LOAD', 'BOUNDARY_DIS_RBODY_LOAD', 'BOUNDARY_PRES_NODAL_LOAD', 'BOUNDARY_VEL_NODAL_LOAD', 'BOUNDARY_VEL_RBODY_LOAD', 'CESE', 'CESE_DRAG_DATA', 'CESE_NODE_DATA', 'CESE_POINT_DATA', 'CESE_SEGMENT_DATA', 'CONTACT', 'CONTACT_ENERGIES', 'CONTACT_FORCES', 'CURVOUT', 'EM', 'EM_BOUNDARYOUT_DATA', 'EM_CIRCUIT0D_DATA', 'EM_CIRCUITRES_DATA', 'EM_CIRCUIT_DATA', 'EM_GLOBAL_DATA', 'EM_ISOPOTCONNOUT_DATA', 'EM_ISOPOTOUT_DATA', 'EM_NODE_DATA', 'EM_PARTDATA_DATA', 'EM_POINT_DATA', 'EM_RANDLESCELL_DATA', 'EM_RISC_DATA', 'EM_ROGOCOIL_DATA', 'FSI', 'FSI_SENSOR_DATA', 'FSI_SURFACE_DATA', 'GEOMETRIC_CONTACT', 'ICFD', 'ICFD_DRAG_DATA', 'ICFD_NODE_DATA', 'ICFD_POINT_DATA', 'ICFD_THERMAL_DATA', 'JOINT', 'JOINT_FLEXION_TORSION', 'JOINT_GENERALIZED', 'JOINT_JOINT', 'JOINT_TRANSLATIONAL', 'MASS', 'MODEL', 'NODAL_RB', 'NODAL_RB_BODY', 'NODAL_RB_PART', 'NODE', 'NODE_GROUP', 'NODE_GROUP_GROUPS', 'NODE_GROUP_NODES', 'PART', 'PART_GROUP', 'PBLAST', 'PBLAST_DATA', 'PBLAST_PART', 'PRETENSIONER', 'PRTUBE', 'PULLEY', 'RETRACTOR', 'RIGIDWALL', 'SEATBELT', 'SHELL', 'SLIPRING', 'SOLID', 'SPC', 'SPC_FORCES', 'SPC_MODEL', 'SPC_MOMENTS', 'SPC_SET', 'SPH', 'SPRING', 'SPRING_ROTATIONAL', 'SPRING_TRANSLATIONAL', 'SUBSYSTEM', 'THICK_SHELL', 'TRACER', 'WELD', 'WELD_ASSEMBLY', 'WELD_CONSTRAINED', 'WELD_GENERALISED', 'WELD_NON_NODAL', 'WELD_SOLID', 'WELD_SPOTWELD_BEAMS', 'X_SECTION'}

    def __getattr__(cls, name):
        if name in EntityType._consts:
            return Oasys.THIS._connection.classGetter(cls.__name__, name)

        raise AttributeError


class Entity(Oasys.gRPC.OasysItem, metaclass=EntityType):


    def __del__(self):
        if not Oasys.THIS._connection:
            return

        Oasys.THIS._connection.destructor(self.__class__.__name__, self._handle)


    def __getattr__(self, name):
        raise AttributeError


    def __setattr__(self, name, value):
# Set the property locally
        self.__dict__[name] = value



import Oasys.gRPC


# Metaclass for static properties and constants
class GraphType(type):
    _consts = {'AXIS_LINEAR', 'AXIS_LOG', 'FONT_COURIER_BOLD', 'FONT_COURIER_MEDIUM', 'FONT_DEFAULT', 'FONT_HELVETICA_BOLD', 'FONT_HELVETICA_MEDIUM', 'FONT_SIZE_10', 'FONT_SIZE_12', 'FONT_SIZE_14', 'FONT_SIZE_18', 'FONT_SIZE_24', 'FONT_SIZE_8', 'FONT_SIZE_AUTO', 'FONT_TIMES_BOLD', 'FONT_TIMES_MEDIUM', 'GRID_OFF', 'GRID_ON', 'LEGEND_1_COLUMN', 'LEGEND_2_COLUMN', 'LEGEND_AUTO', 'LEGEND_COLUMN_LIST', 'LEGEND_FLOATING', 'LEGEND_OFF', 'NO', 'OFF', 'ON', 'PREFIX_AUTO', 'PREFIX_DIR', 'PREFIX_MODEL_NUMBER', 'PREFIX_OFF', 'PREFIX_ON', 'PREFIX_THF', 'PREFIX_USER_DEFINED', 'YES'}

    def __getattr__(cls, name):
        if name in GraphType._consts:
            return Oasys.THIS._connection.classGetter(cls.__name__, name)

        raise AttributeError


class Graph(Oasys.gRPC.OasysItem, metaclass=GraphType):
    _props = {'active', 'add_x_units', 'add_y2_units', 'add_y_units', 'auto_title', 'auto_xlabel', 'auto_xmax', 'auto_xmin', 'auto_y2label', 'auto_y2max', 'auto_y2min', 'auto_ylabel', 'auto_ymax', 'auto_ymin', 'background_colour', 'foreground_colour', 'grid', 'id', 'legend_background_colour', 'legend_background_trans', 'legend_font', 'legend_font_colour', 'legend_font_size', 'legend_layout', 'legend_prefix_format', 'legend_show_prefix', 'legend_show_user_lines', 'legend_user_line_1', 'legend_user_line_1_size', 'legend_user_line_2', 'legend_user_line_2_size', 'legend_user_line_3', 'legend_user_line_3_size', 'legend_user_line_4', 'legend_user_line_4_size', 'legend_user_line_5', 'legend_user_line_5_size', 'legend_user_line_6', 'legend_user_line_6_size', 'legend_user_lines_colour', 'legend_user_lines_font', 'num_legend_columns', 'show_title', 'show_xlabel', 'show_y2label', 'show_ylabel', 'title', 'x_axis_type', 'x_unit_colour', 'x_unit_decimals', 'x_unit_font', 'x_unit_format', 'x_unit_size', 'xlabel', 'xlabel_colour', 'xlabel_font', 'xlabel_size', 'xmax', 'xmin', 'y2_axis_type', 'y2_unit_colour', 'y2_unit_decimals', 'y2_unit_font', 'y2_unit_format', 'y2_unit_size', 'y2label', 'y2label_colour', 'y2label_font', 'y2label_size', 'y2max', 'y2min', 'y_axis_type', 'y_unit_colour', 'y_unit_decimals', 'y_unit_font', 'y_unit_format', 'y_unit_size', 'ylabel', 'ylabel_colour', 'ylabel_font', 'ylabel_size', 'ymax', 'ymin'}


    def __del__(self):
        if not Oasys.THIS._connection:
            return

        Oasys.THIS._connection.destructor(self.__class__.__name__, self._handle)


    def __getattr__(self, name):
# If one of the properties we define then get it
        if name in Graph._props:
            return Oasys.THIS._connection.instanceGetter(self.__class__.__name__, self._handle, name)

        raise AttributeError


    def __setattr__(self, name, value):
# If one of the properties we define then set it
        if name in Graph._props:
            Oasys.THIS._connection.instanceSetter(self.__class__.__name__, self._handle, name, value)
            return

# Set the property locally
        self.__dict__[name] = value


# Constructor
    def __init__(self, index=Oasys.gRPC.defaultArg):
        handle = Oasys.THIS._connection.constructor(self.__class__.__name__, index)
        Oasys.gRPC.OasysItem.__init__(self, self.__class__.__name__, handle)
        """
        Create a new Graph

        Parameters
        ----------
        index : integer
            Optional. Graph index to copy initial display and axis settings from (optional). 
            If not defined then the display and axis settings will be copied from those defined in the preference file

        Returns
        -------
        Graph
            Graph object
        """


# Static methods
    def DeleteFromID(id):
        """
        Deletes a graph

        Parameters
        ----------
        id : integer
            ID of graph to delete

        Returns
        -------
        None
            No return value
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "DeleteFromID", id)

    def GetFromID(id):
        """
        Returns the graph object for a given graph id

        Parameters
        ----------
        id : integer
            ID of graph to return the graph for

        Returns
        -------
        Graph
            Graph object or None if graph does not exists
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "GetFromID", id)

    def Total():
        """
        Returns the total number of graphs

        Returns
        -------
        int
            integer
        """
        return Oasys.THIS._connection.classMethod(__class__.__name__, "Total")



# Instance methods
    def AddCurveID(self, curve_id, no_redraw=Oasys.gRPC.defaultArg):
        """
        Adds a curve to the graph

        Parameters
        ----------
        curve_id : Integer
            ID of the curve to add
        no_redraw : Integer
            Optional. If this argument is 1 then the graph will not be redrawn after the curve is added. This is to be used if a large number of curves are to be added to a graph, so as to avoid the same curves being drawn multiple times. No argument or 0 will trigger a redraw after the curve is added

        Returns
        -------
        bool
            Returns True if the curve is successfully added to the graph else it would return False
        """
        return Oasys.THIS._connection.instanceMethod(self.__class__.__name__, self._handle, "AddCurveID", curve_id, no_redraw)

    def AddToPage(self, page_number):
        """
        Adds the graph to the page

        Parameters
        ----------
        page_number : Integer
            Page number for which to add the graph to

        Returns
        -------
        bool
            Returns True if the graph is successfully added to the page else it would return False
        """
        return Oasys.THIS._connection.instanceMethod(self.__class__.__name__, self._handle, "AddToPage", page_number)

    def Delete(self):
        """
        Deletes the graph

        Returns
        -------
        None
            No return value
        """
        return Oasys.THIS._connection.instanceMethod(self.__class__.__name__, self._handle, "Delete")

    def GetAllCurveIDs(self):
        """
        Returns the IDs of the curves present in the graph in a list

        Returns
        -------
        list
            Array of curve IDs
        """
        return Oasys.THIS._connection.instanceMethod(self.__class__.__name__, self._handle, "GetAllCurveIDs")

    def GetAllPageIDs(self):
        """
        Returns all the pages containing the graph

        Returns
        -------
        list
            Array of page IDs
        """
        return Oasys.THIS._connection.instanceMethod(self.__class__.__name__, self._handle, "GetAllPageIDs")

    def GetNumCurves(self):
        """
        Returns number curves present in the graph

        Returns
        -------
        int
            Number of curves present in the graph
        """
        return Oasys.THIS._connection.instanceMethod(self.__class__.__name__, self._handle, "GetNumCurves")

    def Lock(self, lock_type):
        """
        Locks the blanking status of either blanked curves, unblanked curves or all curves on the graph

        Parameters
        ----------
        lock_type : Integer
            No argument or 0 to lock blanked curves, -1 to unlock blanked curves, -2 to unfreeze all visible curves

        Returns
        -------
        None
            No return value
        """
        return Oasys.THIS._connection.instanceMethod(self.__class__.__name__, self._handle, "Lock", lock_type)

    def RemoveCurveID(self, id):
        """
        Removes a curve from the graph

        Parameters
        ----------
        id : Integer
            ID of the curve to be removed

        Returns
        -------
        bool
            Returns True if the curve is successfully removed from the graph else it would return False
        """
        return Oasys.THIS._connection.instanceMethod(self.__class__.__name__, self._handle, "RemoveCurveID", id)

    def RemoveFromPage(self, id):
        """
        Removes the graph from a page

        Parameters
        ----------
        id : Integer
            ID of the page from which the graph is to be removed

        Returns
        -------
        bool
            Returns True if the graph is successfully removed from the page else it would return False
        """
        return Oasys.THIS._connection.instanceMethod(self.__class__.__name__, self._handle, "RemoveFromPage", id)

